@@ -1,13 +1,15 @@
 #!/usr/bin/env bash
 #
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 #
 # Build script for OpenLineage SQL parser.
 # It's assumed that it will be run on MacOS
 set -e
 
-if [ -x "$(command -v /usr/local/bin/python3.7)" ]; then
+if [ -x "$(command -v /usr/local/opt/python@3.7/bin/python3)" ]; then
+  /usr/local/opt/python@3.7/bin/python3 -m venv .env
+elif [ -x "$(command -v /usr/local/bin/python3.7)" ]; then
   /usr/local/bin/python3.7 -m venv .env
 elif [ -x "$(command -v python3.7)" ]; then
   python3.7 -m venv .env
