@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 #
 # Install script for building OpenLineage SQL parser.
@@ -25,4 +25,12 @@ rustup target add aarch64-apple-darwin
 
 # Maturin is build tool that we're using. It can build python wheels based on standard Rust Cargo.toml.
 echo "Installing Maturin"
-python3.7 -m pip install maturin
+if [ -x "$(command -v /usr/local/opt/python@3.7/bin/python3)" ]; then
+  /usr/local/opt/python@3.7/bin/python3 -m pip install maturin
+elif [ -x "$(command -v /usr/local/bin/python3.7)" ]; then
+  /usr/local/bin/python3.7 -m pip install maturin
+elif [ -x "$(command -v python3.7)" ]; then
+  python3.7 -m pip install maturin
+else
+  python -m pip install maturin
+fi
